@@ -48,6 +48,9 @@ class Client(object):
     def recurring_add(self, **kw):
         return self.call('recurring_add', **kw)
 
+    def recurring_add_pendingitem(self, **kw):
+        return self.call('recurring_add_pendingitem', **kw)
+
     def recurring_get(self, **kw):
         return self.call('recurring_get', **kw)
 
